pub struct CrashQueryReply {
pub records: Vec<CrashRecord>,
pub error: i32,
pub detail: String,
}Fields
records: Vec<CrashRecord>error: i32detail: StringImplementations
Sourceimpl CrashQueryReply
impl CrashQueryReply
Sourcepub fn error(&self) -> ProbeErrorCode
pub fn error(&self) -> ProbeErrorCode
Returns the enum value of error, or the default if the field is set to an invalid enum value.
Sourcepub fn set_error(&mut self, value: ProbeErrorCode)
pub fn set_error(&mut self, value: ProbeErrorCode)
Sets error to the provided enum value.