pub struct CrashStatsReply {
pub signatures: Vec<CrashSignatureStat>,
pub total: u64,
pub first_unix_ms: u64,
pub last_unix_ms: u64,
pub distinct_classes: u64,
pub error: i32,
pub detail: String,
}Fields
signatures: Vec<CrashSignatureStat>total: u64Total matching crashes, which is NOT the sum of a truncated record page.
first_unix_ms: u64Observed window across matches, both zero when there are none.
last_unix_ms: u64distinct_classes: u64Distinct application classes among matches.
error: i32detail: StringImplementations
Sourceimpl CrashStatsReply
impl CrashStatsReply
Sourcepub fn error(&self) -> ProbeErrorCode
pub fn error(&self) -> ProbeErrorCode
Returns the enum value of error, or the default if the field is set to an invalid enum value.
Sourcepub fn set_error(&mut self, value: ProbeErrorCode)
pub fn set_error(&mut self, value: ProbeErrorCode)
Sets error to the provided enum value.