pub struct JobStatus {
pub job_id: String,
pub state: i32,
pub percent_complete: u32,
pub artifact_path: String,
pub error: i32,
pub detail: String,
}Fields
job_id: Stringstate: i32percent_complete: u32artifact_path: Stringerror: i32detail: StringImplementations
Sourceimpl JobStatus
impl JobStatus
Sourcepub fn state(&self) -> State
pub fn state(&self) -> State
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn error(&self) -> ProbeErrorCode
pub fn error(&self) -> ProbeErrorCode
Returns the enum value of error, or the default if the field is set to an invalid enum value.
Sourcepub fn set_error(&mut self, value: ProbeErrorCode)
pub fn set_error(&mut self, value: ProbeErrorCode)
Sets error to the provided enum value.