pub struct ProcessInfo {Show 14 fields
pub key: Option<ProcessKey>,
pub exe_path: String,
pub app_class: String,
pub app_name: String,
pub app_version: String,
pub instance_name: String,
pub runtime: i32,
pub supported_ops: Vec<i32>,
pub registered_unix_ms: u64,
pub env: HashMap<String, String>,
pub name: String,
pub cwd: String,
pub registered: bool,
pub env_names: Vec<String>,
}Fields
key: Option<ProcessKey>exe_path: Stringapp_class: Stringapp_name: Stringapp_version: Stringinstance_name: Stringruntime: i32supported_ops: Vec<i32>registered_unix_ms: u64env: HashMap<String, String>Only variables the target allowlisted. Never the full environment.
name: Stringcwd: Stringregistered: boolenv_names: Vec<String>Implementations
Sourceimpl ProcessInfo
impl ProcessInfo
Sourcepub fn runtime(&self) -> Runtime
pub fn runtime(&self) -> Runtime
Returns the enum value of runtime, or the default if the field is set to an invalid enum value.
Sourcepub fn set_runtime(&mut self, value: Runtime)
pub fn set_runtime(&mut self, value: Runtime)
Sets runtime to the provided enum value.
Sourcepub fn supported_ops(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<SupportedOp>> ⓘ
pub fn supported_ops( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<SupportedOp>> ⓘ
Returns an iterator which yields the valid enum values contained in supported_ops.
Sourcepub fn push_supported_ops(&mut self, value: SupportedOp)
pub fn push_supported_ops(&mut self, value: SupportedOp)
Appends the provided enum value to supported_ops.