pub struct ProcessQueryReply {
pub processes: Vec<ProcessInfo>,
pub error: i32,
pub detail: String,
}Fields
processes: Vec<ProcessInfo>error: i32detail: StringImplementations
Sourceimpl ProcessQueryReply
impl ProcessQueryReply
Sourcepub fn error(&self) -> ProbeErrorCode
pub fn error(&self) -> ProbeErrorCode
Returns the enum value of error, or the default if the field is set to an invalid enum value.
Sourcepub fn set_error(&mut self, value: ProbeErrorCode)
pub fn set_error(&mut self, value: ProbeErrorCode)
Sets error to the provided enum value.