pub struct ProfileStatus {
pub profile_id: String,
pub kind: i32,
pub running: bool,
pub started_unix_ms: u64,
pub samples_collected: u64,
pub samples_lost: u64,
pub error: i32,
pub detail: String,
}Fields
profile_id: Stringkind: i32running: boolstarted_unix_ms: u64samples_collected: u64samples_lost: u64Non-zero means the sampler could not keep up and the profile under-represents the workload.
error: i32detail: StringImplementations
Sourceimpl ProfileStatus
impl ProfileStatus
Sourcepub fn kind(&self) -> ProfileKind
pub fn kind(&self) -> ProfileKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: ProfileKind)
pub fn set_kind(&mut self, value: ProfileKind)
Sets kind to the provided enum value.
Sourcepub fn error(&self) -> ProbeErrorCode
pub fn error(&self) -> ProbeErrorCode
Returns the enum value of error, or the default if the field is set to an invalid enum value.
Sourcepub fn set_error(&mut self, value: ProbeErrorCode)
pub fn set_error(&mut self, value: ProbeErrorCode)
Sets error to the provided enum value.